@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.7   update date: 2023-06-20
+# Version : 1.4.8   update date: 2023-12-04
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -30,7 +30,7 @@ Usage:
         -d path    The path of dbspace.
         -i path    The path of install software.
         -p path    The path of home path.
-        -s y|n     Value of dbspace is 1GB? Yes/No, default is Y.
+        -s y|n     Value of dbspace is 1GB? Yes/No, default is N.
         -u user    The user name for SYSDBA, gbasedbt/informix, default is gbasedbt
         -l locale  DB_LOCALE/CLIENT_LOCALE value.
         -o y|n     Only install software? Yes/No, default is N.
@@ -55,6 +55,7 @@ INSTALL_DIR=${INSTALL_DIR:-/opt/gbase}
 GBASESERVER=gbase01
 GBASELOCALE=${GBASELOCALE:-zh_CN.utf8}
 PORTNO=9088
+PORTSSL=9089
 
 DATADIR=${DATADIR:-/data/gbase}
 ### dbspace init size.
@@ -66,7 +67,7 @@ SBSPACESIZE=4096000
 TEMPSIZE=4096000
 DATASIZE=10240000
 
-if [ x"$DBS1GB" = xy -o x"$DBS1GB" = xY ]; then
+if [[ x"$DBS1GB" = xy || x"$DBS1GB" = xY ]]; then
   ROOTSIZE=1024000
   PLOGSIZE=1024000
   LLOGSIZE=1024000
@@ -253,7 +254,7 @@ export ${USER_UPPER}SQLHOSTS=${INSTALL_DIR}/etc/sqlhosts
 export DB_LOCALE=${GBASELOCALE}
 export CLIENT_LOCALE=${GBASELOCALE}
 export GL_USEGLU=1
-# exprot NODEFDAC=yes
+# export NODEFDAC=yes
 export DBDATE="Y4MD-"
 export DBACCESS_SHOW_TIME=1
 EOF
@@ -263,7 +264,7 @@ loginfo "Building ${INSTALL_DIR}/etc/sqlhosts ."
 # echo "$GBASESERVER onsoctcp 0.0.0.0 ${PORTNO:-9088}" > $INSTALL_DIR/etc/sqlhosts
 cat > $INSTALL_DIR/etc/sqlhosts <<EOF 2>/dev/null
 ${GBASESERVER}     onsoctcp 0.0.0.0 ${PORTNO:-9088}
-${GBASESERVER}_shm onipcshm 0.0.0.0 ${PORTNO:-9099}
+${GBASESERVER}_ssl onsoctcp 0.0.0.0 ${PORTSSL:-9089}
 EOF
 chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/sqlhosts
 chmod 0644 $INSTALL_DIR/etc/sqlhosts
@@ -278,7 +279,7 @@ loginfo "Building $CFGFILE ."
 sed -i "s#^ROOTPATH.*#ROOTPATH $DATADIR/rootchk#g" $CFGFILE
 sed -i "s#^ROOTSIZE.*#ROOTSIZE $ROOTSIZE#g" $CFGFILE
 sed -i "s#^DBSERVERNAME.*#DBSERVERNAME $GBASESERVER#g" $CFGFILE
-sed -i "s#^DBSERVERALIASES.*#DBSERVERALIASES ${GBASESERVER}_shm#g" $CFGFILE
+sed -i "s#^DBSERVERALIASES.*#DBSERVERALIASES ${GBASESERVER}_ssl#g" $CFGFILE
 sed -i "s#^TAPEDEV.*#TAPEDEV /dev/null#g" $CFGFILE
 sed -i "s#^LTAPEDEV.*#LTAPEDEV /dev/null#g" $CFGFILE
 sed -i "s#^USERMAPPING.*#USERMAPPING ADMIN#g" $CFGFILE
@@ -384,7 +385,35 @@ loginfo "Changing auto extend able on for chunk datadbs01"
 ADMIN_SQLFILE=${INSTALL_DIR}/temp/admin_sqlfile.sql
 mkdir -p ${INSTALL_DIR}/temp
 cat << ! > $ADMIN_SQLFILE 2>&1
+-- set datadbs01 extendable
 EXECUTE FUNCTION task ("modify chunk extendable on", 6);
+-- set all task not run except idle_user_timeout
+update ph_task set tk_enable = 'f';
+update ph_task set tk_frequency = interval(00:30:00) hour to second, tk_enable = 't' 
+where tk_name = 'idle_user_timeout';
+-- procedure
+drop procedure if exists delete_task_logs;
+create procedure delete_task_logs()
+  define v_datestr varchar(40);
+  select current year to second - value::interval day to second
+  into v_datestr
+  from ph_threshold
+  where task_name = 'delete_task_logs';
+  if v_datestr is null OR v_datestr <> '' then
+    delete from command_history where cmd_exec_time < v_datestr;
+    delete from ph_run where run_time < v_datestr;
+    -- delete from ph_alerts where alert_time < v_datestr;
+  end if;
+end procedure;
+-- add task delete_task_logs into ph_threshold
+delete from ph_threshold where task_name = 'delete_task_logs';
+insert into ph_threshold (id, name, task_name, value, value_type, description)
+values(0,'DELETE ALL SYSADMIN LOGS','delete_task_logs','1 00:00:00','STRING','Delete command_history and ph_run logs');
+-- add task delete_task_logs into ph_task
+delete from ph_task where tk_name = 'delete_task_logs';
+insert into ph_task( tk_name, tk_description, tk_type, tk_dbs, tk_execute, tk_start_time, tk_stop_time, tk_frequency, tk_group, tk_enable)
+values('delete_task_logs','Delete command_history and ph_run logs','TASK','sysadmin','execute procedure delete_task_logs()',
+       DATETIME(00:05:00) hour to second , DATETIME(01:00:00) hour to second, INTERVAL ( 1 ) DAY TO DAY, 'MISC','t');
 !
 if [ -s $ADMIN_SQLFILE ]; then
   chown ${USER_NAME}:${USER_NAME} ${INSTALL_DIR}/temp
@@ -398,6 +427,7 @@ ADMIN_SQLFILE=${INSTALL_DIR}/temp/mapping_sqlfile.sql
 mkdir -p ${INSTALL_DIR}/temp
 cat << ! > $ADMIN_SQLFILE 2>&1
 CREATE DEFAULT USER WITH PROPERTIES USER daemon HOME "${USER_HOME}/users";
+create user dbtuser with password "$USER_PASS";
 !
 if [ -s $ADMIN_SQLFILE ]; then
   chown ${USER_NAME}:${USER_NAME} ${INSTALL_DIR}/temp
@@ -442,6 +472,7 @@ CRDB_SQLFILE=${INSTALL_DIR}/temp/crdb_sqlfile.sql
 mkdir -p ${INSTALL_DIR}/temp
 cat << ! > $CRDB_SQLFILE 2>&1
 create database testdb in datadbs01 with log;
+grant dba to dbtuser;
 !
 if [ -s $CRDB_SQLFILE ]; then
   chown ${USER_NAME}:${USER_NAME} ${INSTALL_DIR}/temp
@@ -450,12 +481,12 @@ if [ -s $CRDB_SQLFILE ]; then
 fi
 
 ###### change config
-loginfo "Creating file \$INSTALL_DIR/etc/sysadmin/stop ."
-if [ ! -f $INSTALL_DIR/etc/sysadmin/stop ]; then
-  touch $INSTALL_DIR/etc/sysadmin/stop
-  chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/sysadmin/stop
-  chmod 0644 $INSTALL_DIR/etc/sysadmin/stop
-fi
+#loginfo "Creating file \$INSTALL_DIR/etc/sysadmin/stop ."
+#if [ ! -f $INSTALL_DIR/etc/sysadmin/stop ]; then
+#  touch $INSTALL_DIR/etc/sysadmin/stop
+#  chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/sysadmin/stop
+#  chmod 0644 $INSTALL_DIR/etc/sysadmin/stop
+#fi
 
 ## cfg with static value
 loginfo "Optimizing database config."
@@ -479,6 +510,7 @@ sed -i "s#^DS_NONPDQ_QUERY_MEM.*#DS_NONPDQ_QUERY_MEM 256000#g" $CFGFILE
 sed -i "s#^TEMPTAB_NOLOG.*#TEMPTAB_NOLOG 1#g" $CFGFILE
 sed -i "s#^DUMPSHMEM.*#DUMPSHMEM 0#g" $CFGFILE
 # sed -i "s#^IFX_FOLDVIEW.*#IFX_FOLDVIEW 0#g" $CFGFILE
+sed -i "s#^OPT_GOAL.*#OPT_GOAL 0#g" $CFGFILE
 
 if [ $NUMMEM -le 4096 ]; then
   sed -i "s#^DS_TOTAL_MEMORY.*#DS_TOTAL_MEMORY 128000#g" $CFGFILE
@@ -525,6 +557,8 @@ PORT NUMBER     : $PORTNO
 JDBC URL        : jdbc:${USER_NAME}-sqli://IPADDR:$PORTNO/testdb:${USER_UPPER}SERVER=$GBASESERVER;DB_LOCALE=$GBASELOCALE;CLIENT_LOCALE=$GBASELOCALE;IFX_LOCK_MODE_WAIT=10
 JDBC USERNAME   : $USER_NAME
 JDBC PASSWORD   : $USER_PASS
+INNER USERNAME  : dbtuser
+INNER PASSWORD  : $USER_PASS
 
 EOF
 
