@@ -3,7 +3,7 @@
 # Filename: CleanAll.sh
 # Function: Clean GBase 8s Auto Install.
 # Write by: liaosnet@gbasedbt.com
-# Version : 1.4.5   update date: 2023-05-11
+# Version : 1.4.8   update date: 2023-12-04
 ##################################################################
 ##### Define Parameter
 ##### Get Parameter
@@ -28,6 +28,7 @@ Usage:
 done
 
 USER_NAME=${USER_NAME:-gbasedbt}
+USER_UPPER=$(echo $USER_NAME|tr [a-z] [A-Z])
 WORKDIR=$(pwd)
 
 #### do clean
@@ -37,8 +38,8 @@ if [ $? -gt 0 ];then
     exit 2
 fi
 
-INSTALL_DIR=$(su - ${USER_NAME} -c "env | grep GBASEDBTDIR")
-INSTALL_DIR=${INSTALL_DIR#*=}
+INSTALL_DIR=$(head -n 1 /${USER_UPPER}TMP/.infxdirs)
+
 su - ${USER_NAME} -c "onmode -ky" 2>/dev/null
 su - ${USER_NAME} -c "onclean -ky" 2>/dev/null
 ps -ef | awk '/oninit/ && $3==1{print "kill -9 "$2}' | sh 2>/dev/null
